@@ -1,4 +1,5 @@
-package CDBase;
+package # hide from PAUSE 
+    CDBase;
 
 use strict;
 use base qw(DBIx::Class::Test::SQLite);
